@@ -11,8 +11,7 @@ describe 'swift::proxy::cache' do
   end
 
   let :pre_condition do
-    'class { "concat::setup": }
-     concat { "/etc/swift/proxy-server.conf": }
+    'concat { "/etc/swift/proxy-server.conf": }
      class { "memcached": max_memory => 1 }'
   end
 
