@@ -8,8 +8,7 @@ describe 'swift::proxy::swift3' do
   end
 
   let :pre_condition do
-    'class { "concat::setup": }
-     concat { "/etc/swift/proxy-server.conf": }'
+    'concat { "/etc/swift/proxy-server.conf": }'
   end
 
   let :fragment_file do
