@@ -36,10 +36,11 @@ describe 'swift::storage::container' do
         it 'configures services' do
           platform_params[:service_names].each do |service_alias, service_name|
             is_expected.to contain_service(service_alias).with(
-              :name    => service_name,
-              :ensure  => (param_hash[:manage_service] && param_hash[:enabled]) ? 'running' : 'stopped',
-              :enable  => param_hash[:enabled],
-              :tag     => 'swift-service',
+              :name     => service_name,
+              :ensure   => (param_hash[:manage_service] && param_hash[:enabled]) ? 'running' : 'stopped',
+              :enable   => param_hash[:enabled],
+              :provider => platform_params[:service_provider],
+              :tag      => 'swift-service',
             )
           end
         end
@@ -75,29 +76,36 @@ describe 'swift::storage::container' do
 
     let :platform_params do
       { :service_names => {
-          'swift-container'            => 'swift-container',
+          'swift-container-server'     => 'swift-container',
           'swift-container-replicator' => 'swift-container-replicator',
           'swift-container-updater'    => 'swift-container-updater',
           'swift-container-auditor'    => 'swift-container-auditor'
-        }
+        },
+        :service_provider => 'upstart'
       }
     end
 
     it_configures 'swift-storage-container'
 
-    context 'Ubuntu specific resources' do
-      it 'configures sync' do
-        is_expected.to contain_service('swift-container-sync').with(
-          :ensure   => 'running',
-          :enable   => true,
-          :provider => 'upstart',
-          :require  => 'File[/etc/init/swift-container-sync.conf]',
-        )
-        is_expected.to contain_file('/etc/init/swift-container-sync.conf').with(
-          :source  => 'puppet:///modules/swift/swift-container-sync.conf.upstart',
-          :require => 'Package[swift-container]'
-        )
+    context 'on debian using swiftinit service provider' do
+
+      before do
+        params.merge!({ :service_provider => 'swiftinit' })
       end
+
+      let :platform_params do
+        { :service_names => {
+            'swift-container-server'     => 'swift-container-server',
+            'swift-container-replicator' => 'swift-container-replicator',
+            'swift-container-updater'    => 'swift-container-updater',
+            'swift-container-auditor'    => 'swift-container-auditor',
+            'swift-container-sync'       => 'swift-container-sync'
+          },
+          :service_provider => 'swiftinit'
+        }
+      end
+
+      it_configures 'swift-storage-container'
     end
   end
 
@@ -109,7 +117,7 @@ describe 'swift::storage::container' do
 
     let :platform_params do
       { :service_names => {
-          'swift-container'            => 'openstack-swift-container',
+          'swift-container-server'     => 'openstack-swift-container',
           'swift-container-replicator' => 'openstack-swift-container-replicator',
           'swift-container-updater'    => 'openstack-swift-container-updater',
           'swift-container-auditor'    => 'openstack-swift-container-auditor'
@@ -119,23 +127,24 @@ describe 'swift::storage::container' do
 
     it_configures 'swift-storage-container'
 
-    context 'RedHat specific resources' do
+    context 'on redhat using swiftinit service provider' do
+
       before do
-        params.merge!({ :allowed_sync_hosts => ['127.0.0.1', '10.1.0.1', '10.1.0.2'] })
+        params.merge!({ :service_provider => 'swiftinit' })
       end
 
-      let :pre_condition do
-         "class { 'swift': swift_hash_suffix => 'foo' }
-         class { 'swift::storage::all': storage_local_net_ip => '10.0.0.1' }"
+      let :platform_params do
+        { :service_names => {
+            'swift-container-server'     => 'swift-container-server',
+            'swift-container-replicator' => 'swift-container-replicator',
+            'swift-container-updater'    => 'swift-container-updater',
+            'swift-container-auditor'    => 'swift-container-auditor',
+          },
+          :service_provider => 'swiftinit'
+        }
       end
 
-      let :fragment_file do
-        "/var/lib/puppet/concat/_etc_swift_container-server.conf/fragments/00_swift-container-6001"
-      end
-
-      it {
-        is_expected.to contain_file(fragment_file).with_content(/^allowed_sync_hosts = 127.0.0.1,10.1.0.1,10.1.0.2$/)
-      }
+      it_configures 'swift-storage-container'
     end
   end
 end
