@@ -10,8 +10,7 @@ describe 'swift::storage::filter::recon' do
   end
 
   let :pre_condition do
-    'class { "concat::setup": }
-     concat { "/etc/swift/dummy-server.conf": }'
+    'concat { "/etc/swift/dummy-server.conf": }'
   end
 
   let :fragment_file do
